@@ -22,16 +22,7 @@ class Skyline:
         self.year = year
         self.skyline_type = skyline_type
         self.number_by_date_dict = number_by_date_dict
-        self.type_info_dict = {
-            "duolingo": "Duolingo",
-            "github": "GitHub",
-            "leetcode": "LeetCode",
-            "twitter": "Twitter",
-            "youtube": "YouTube",
-            "gitlab": "GitLab",
-            "strava": "Strava",
-            "bilibili": "bilibili",
-        }
+        self.type_info_dict = None
         assert len(user_name) < 16
         self.user_name = user_name
 
@@ -72,7 +63,7 @@ class Skyline:
     def _make_skyline_card(self, text_info, offset=0):
         # TODO change the magic numbers
         # support change font
-        FONT = os.path.join(github_poster.skyline.__path__[0], "font", "arial.ttf")
+        FONT = os.path.join(github_poster.skyline.__path__[0], "font", "hei.ttf")
         TEXT = text_info
         w, h = measure_text(FONT, TEXT)
         t = (
